@@ -2,17 +2,15 @@
 # -*- coding: utf-8 -*-
 """Initialization for berhoel python namespace packages.
 """
-from __future__ import (
-    division, print_function, absolute_import, unicode_literals)
 
-__date__ = "2018/09/30 00:24:55 hoel"
+__date__ = "2021/12/11 17:51:35 hoel"
 __author__ = "Berthold Höllmann"
 __copyright__ = "Copyright © 2018 by Berthold Höllmann"
 __credits__ = ["Berthold Höllmann"]
 __maintainer__ = "Berthold Höllmann"
 __email__ = "berhoel@gmail.com"
 
-__import__('pkg_resources').declare_namespace(__name__)
+__import__("pkg_resources").declare_namespace(__name__)
 
 
 # Local Variables:
