@@ -54,9 +54,7 @@ True
 >>>
 """
 
-from __future__ import division, print_function, absolute_import
-
-__date__ = "2020/06/13 17:42:09 hoel"
+__date__ = "2021/12/11 17:48:58 hoel"
 __author__ = "Berthold Höllmann"
 __copyright__ = "Copyright © 1998-2000,2018 by Berthold Höllmann"
 __credits__ = ["Berthold Höllmann"]
@@ -66,8 +64,7 @@ __email__ = "berhoel@gmail.com"
 
 class ArgError(TypeError):
     """
-Error from the argument checking.
-"""
+    Error from the argument checking."""
 
     pass
 
@@ -75,14 +72,14 @@ Error from the argument checking.
 class CheckArgs:
     """A wrapper around the ``check_args`` function.
 
-Args:
-    default (tuple[tuple[str, object]]): argument names and default values for ``__init__`` method.
-    data (tuple): arguments to ``__init__`` method.
-    kw (dict): keyword arguments to ``__init__`` method.
+    Args:
+        default (tuple[tuple[str, object]]): argument names and default values for ``__init__`` method.
+        data (tuple): arguments to ``__init__`` method.
+        kw (dict): keyword arguments to ``__init__`` method.
+
+    Returns:
+        dict: argument name, value pairs."""
 
-Returns:
-    dict: argument name, value pairs.
-"""
     def __init__(self, *data, **kw):
         self.args = check_args(self.default, data, kw, self.__class__.__name__)
 
@@ -90,15 +87,14 @@ Returns:
 def check_args(default, data, kw, name):
     """Check arguments for function.
 
-Args:
-    default (tuple[tuple[str, object]]): argument names and default values for function call.
-    data (tuple): arguments to function call.
-    kw (dict): keyword arguments to function call.
-    name (str): name for reporting.
+    Args:
+        default (tuple[tuple[str, object]]): argument names and default values for function call.
+        data (tuple): arguments to function call.
+        kw (dict): keyword arguments to function call.
+        name (str): name for reporting.
 
-Returns:
-    dict: argument name, value pairs.
-"""
+    Returns:
+        dict: argument name, value pairs."""
     args = dict(default)
     arglen = len(default)
     if (len(data) + len(kw)) > arglen:
